@@ -30,11 +30,14 @@ class Parameters:
     # ENTORNO POR DEFECTO
     environment = platform.system()
     enviroment_confguration = os.getenv('PYBOT_SYSTEM')
+    environment_record = os.getenv('PYBOT_RECORD')
 
-    # CONFIOGURACION DE BROWSER Y PRUEBAS
-    browser = 'CHROME'
+    # CONFIGURACION DE BROWSER Y PRUEBAS
+    browser = 'EDGE' if enviroment_confguration is None else 'CHROME'
     debug = False
     headless = False
+
+    record = record = False if environment_record is None else False if environment_record.lower() == "false" else bool(environment_record)
     #VARIABLE LISTA DE PASOS
     steps_list = []
 
